summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAdriaan de Groot <groot@kde.org>2019-02-12 05:38:53 -0500
committerAdriaan de Groot <groot@kde.org>2019-02-12 05:40:11 -0500
commita4e6d4cd3548217fd6a843d0b47dbbb1c12e9c15 (patch)
tree0c46c950ab0bcf2655979087db9cb08a9775471f
parentae714278a598238941d22c4be39f8f8eeb5febb0 (diff)
[partition] Rename combo box
- Too much confusion possible between the different members all named variations of *SwapChoice* - Update copyright years, too
-rw-r--r--src/modules/partition/gui/ChoicePage.cpp16
-rw-r--r--src/modules/partition/gui/ChoicePage.h4
2 files changed, 10 insertions, 10 deletions
diff --git a/src/modules/partition/gui/ChoicePage.cpp b/src/modules/partition/gui/ChoicePage.cpp
index 10ffbcee3..f62af013f 100644
--- a/src/modules/partition/gui/ChoicePage.cpp
+++ b/src/modules/partition/gui/ChoicePage.cpp
@@ -1,7 +1,7 @@
/* === This file is part of Calamares - <https://github.com/calamares> ===
*
* Copyright 2014-2017, Teo Mrnjavac <teo@kde.org>
- * Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
+ * Copyright 2017-2019, Adriaan de Groot <groot@kde.org>
* Copyright 2019, Collabora Ltd
*
* Calamares is free software: you can redistribute it and/or modify
@@ -100,7 +100,7 @@ ChoicePage::ChoicePage( const SwapChoiceSet& swapChoices, QWidget* parent )
, m_eraseButton( nullptr )
, m_replaceButton( nullptr )
, m_somethingElseButton( nullptr )
- , m_eraseSwapChoices( nullptr )
+ , m_eraseSwapChoiceComboBox( nullptr )
, m_deviceInfoWidget( nullptr )
, m_beforePartitionBarsView( nullptr )
, m_beforePartitionLabelsView( nullptr )
@@ -270,8 +270,8 @@ ChoicePage::setupChoices()
// .. TODO: only if enabled in the config
if ( m_availableSwapChoices.count() > 1 )
{
- m_eraseSwapChoices = createCombo( m_availableSwapChoices );
- m_eraseButton->addOptionsComboBox( m_eraseSwapChoices );
+ m_eraseSwapChoiceComboBox = createCombo( m_availableSwapChoices );
+ m_eraseButton->addOptionsComboBox( m_eraseSwapChoiceComboBox );
}
m_itemsLayout->addWidget( m_alongsideButton );
@@ -316,14 +316,14 @@ ChoicePage::setupChoices()
connect( this, &ChoicePage::actionChosen,
this, &ChoicePage::onActionChanged );
- if ( m_eraseSwapChoices )
- connect( m_eraseSwapChoices, QOverload<int>::of(&QComboBox::currentIndexChanged),
+ if ( m_eraseSwapChoiceComboBox )
+ connect( m_eraseSwapChoiceComboBox, QOverload<int>::of(&QComboBox::currentIndexChanged),
this, &ChoicePage::onActionChanged );
CALAMARES_RETRANSLATE(
m_somethingElseButton->setText( tr( "<strong>Manual partitioning</strong><br/>"
"You can create or resize partitions yourself." ) );
- updateSwapChoicesTr( m_eraseSwapChoices );
+ updateSwapChoicesTr( m_eraseSwapChoiceComboBox );
)
}
@@ -448,7 +448,7 @@ ChoicePage::applyActionChoice( ChoicePage::InstallChoice choice )
m_encryptWidget->passphrase(),
gs->value( "efiSystemPartition" ).toString(),
CalamaresUtils::GiBtoBytes( gs->value( "requiredStorageGB" ).toDouble() ),
- static_cast<PartitionActions::Choices::SwapChoice>( m_eraseSwapChoices->currentData().toInt() )
+ static_cast<PartitionActions::Choices::SwapChoice>( m_eraseSwapChoiceComboBox->currentData().toInt() )
};
if ( m_core->isDirty() )
diff --git a/src/modules/partition/gui/ChoicePage.h b/src/modules/partition/gui/ChoicePage.h
index 0d25c61ee..527a59e1a 100644
--- a/src/modules/partition/gui/ChoicePage.h
+++ b/src/modules/partition/gui/ChoicePage.h
@@ -1,7 +1,7 @@
/* === This file is part of Calamares - <https://github.com/calamares> ===
*
* Copyright 2014-2016, Teo Mrnjavac <teo@kde.org>
- * Copyright 2018, Adriaan de Groot <groot@kde.org>
+ * Copyright 2018-2019, Adriaan de Groot <groot@kde.org>
* Copyright 2019, Collabora Ltd
*
* Calamares is free software: you can redistribute it and/or modify
@@ -155,7 +155,7 @@ private:
PrettyRadioButton* m_eraseButton;
PrettyRadioButton* m_replaceButton;
PrettyRadioButton* m_somethingElseButton;
- QComboBox* m_eraseSwapChoices; // UI, see also m_swapChoices
+ QComboBox* m_eraseSwapChoiceComboBox; // UI, see also m_eraseSwapChoice
DeviceInfoWidget* m_deviceInfoWidget;